# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/planning_stats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/planning_stats.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+modules/planning/proto/planning_stats.proto\x12\x0f\x61pollo.planning\"Z\n\nStatsGroup\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x18\n\x03min\x18\x02 \x01(\x01:\x0b\x31\x30\x30\x30\x30\x30\x30\x30\x30\x30\x30\x12\x0b\n\x03sum\x18\x03 \x01(\x01\x12\x0b\n\x03\x61vg\x18\x04 \x01(\x01\x12\x0b\n\x03num\x18\x05 \x01(\x05\"\xa6\x02\n\rPlanningStats\x12\x36\n\x11total_path_length\x18\x01 \x01(\x0b\x32\x1b.apollo.planning.StatsGroup\x12\x34\n\x0ftotal_path_time\x18\x02 \x01(\x0b\x32\x1b.apollo.planning.StatsGroup\x12&\n\x01v\x18\x03 \x01(\x0b\x32\x1b.apollo.planning.StatsGroup\x12&\n\x01\x61\x18\x04 \x01(\x0b\x32\x1b.apollo.planning.StatsGroup\x12*\n\x05kappa\x18\x05 \x01(\x0b\x32\x1b.apollo.planning.StatsGroup\x12+\n\x06\x64kappa\x18\x06 \x01(\x0b\x32\x1b.apollo.planning.StatsGroup'
)




_STATSGROUP = _descriptor.Descriptor(
  name='StatsGroup',
  full_name='apollo.planning.StatsGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max', full_name='apollo.planning.StatsGroup.max', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='apollo.planning.StatsGroup.min', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10000000000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sum', full_name='apollo.planning.StatsGroup.sum', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg', full_name='apollo.planning.StatsGroup.avg', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num', full_name='apollo.planning.StatsGroup.num', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=154,
)


_PLANNINGSTATS = _descriptor.Descriptor(
  name='PlanningStats',
  full_name='apollo.planning.PlanningStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_path_length', full_name='apollo.planning.PlanningStats.total_path_length', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_path_time', full_name='apollo.planning.PlanningStats.total_path_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='apollo.planning.PlanningStats.v', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='apollo.planning.PlanningStats.a', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa', full_name='apollo.planning.PlanningStats.kappa', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dkappa', full_name='apollo.planning.PlanningStats.dkappa', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=451,
)

_PLANNINGSTATS.fields_by_name['total_path_length'].message_type = _STATSGROUP
_PLANNINGSTATS.fields_by_name['total_path_time'].message_type = _STATSGROUP
_PLANNINGSTATS.fields_by_name['v'].message_type = _STATSGROUP
_PLANNINGSTATS.fields_by_name['a'].message_type = _STATSGROUP
_PLANNINGSTATS.fields_by_name['kappa'].message_type = _STATSGROUP
_PLANNINGSTATS.fields_by_name['dkappa'].message_type = _STATSGROUP
DESCRIPTOR.message_types_by_name['StatsGroup'] = _STATSGROUP
DESCRIPTOR.message_types_by_name['PlanningStats'] = _PLANNINGSTATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatsGroup = _reflection.GeneratedProtocolMessageType('StatsGroup', (_message.Message,), {
  'DESCRIPTOR' : _STATSGROUP,
  '__module__' : 'modules.planning.proto.planning_stats_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.StatsGroup)
  })
_sym_db.RegisterMessage(StatsGroup)

PlanningStats = _reflection.GeneratedProtocolMessageType('PlanningStats', (_message.Message,), {
  'DESCRIPTOR' : _PLANNINGSTATS,
  '__module__' : 'modules.planning.proto.planning_stats_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PlanningStats)
  })
_sym_db.RegisterMessage(PlanningStats)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/pbf_tracker_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/pbf_tracker_config.proto',
  package='apollo.perception.fusion',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1modules/perception/proto/pbf_tracker_config.proto\x12\x18\x61pollo.perception.fusion\"\xd1\x01\n\x10PbfTrackerConfig\x12)\n\x12type_fusion_method\x18\x01 \x01(\t:\rDstTypeFusion\x12\x30\n\x14motion_fusion_method\x18\x02 \x01(\t:\x12KalmanMotionFusion\x12+\n\x13shape_fusion_method\x18\x03 \x01(\t:\x0ePbfShapeFusion\x12\x33\n\x17\x65xistence_fusion_method\x18\x04 \x01(\t:\x12\x44stExistenceFusion'
)




_PBFTRACKERCONFIG = _descriptor.Descriptor(
  name='PbfTrackerConfig',
  full_name='apollo.perception.fusion.PbfTrackerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_fusion_method', full_name='apollo.perception.fusion.PbfTrackerConfig.type_fusion_method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"DstTypeFusion".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motion_fusion_method', full_name='apollo.perception.fusion.PbfTrackerConfig.motion_fusion_method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"KalmanMotionFusion".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape_fusion_method', full_name='apollo.perception.fusion.PbfTrackerConfig.shape_fusion_method', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"PbfShapeFusion".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='existence_fusion_method', full_name='apollo.perception.fusion.PbfTrackerConfig.existence_fusion_method', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"DstExistenceFusion".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=289,
)

DESCRIPTOR.message_types_by_name['PbfTrackerConfig'] = _PBFTRACKERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PbfTrackerConfig = _reflection.GeneratedProtocolMessageType('PbfTrackerConfig', (_message.Message,), {
  'DESCRIPTOR' : _PBFTRACKERCONFIG,
  '__module__' : 'modules.perception.proto.pbf_tracker_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.fusion.PbfTrackerConfig)
  })
_sym_db.RegisterMessage(PbfTrackerConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/gain_scheduler_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/gain_scheduler_conf.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/control/proto/gain_scheduler_conf.proto\x12\x0e\x61pollo.control\"E\n\rGainScheduler\x12\x34\n\tscheduler\x18\x01 \x03(\x0b\x32!.apollo.control.GainSchedulerInfo\"1\n\x11GainSchedulerInfo\x12\r\n\x05speed\x18\x01 \x01(\x01\x12\r\n\x05ratio\x18\x02 \x01(\x01'
)




_GAINSCHEDULER = _descriptor.Descriptor(
  name='GainScheduler',
  full_name='apollo.control.GainScheduler',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduler', full_name='apollo.control.GainScheduler.scheduler', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=136,
)


_GAINSCHEDULERINFO = _descriptor.Descriptor(
  name='GainSchedulerInfo',
  full_name='apollo.control.GainSchedulerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.control.GainSchedulerInfo.speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ratio', full_name='apollo.control.GainSchedulerInfo.ratio', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=187,
)

_GAINSCHEDULER.fields_by_name['scheduler'].message_type = _GAINSCHEDULERINFO
DESCRIPTOR.message_types_by_name['GainScheduler'] = _GAINSCHEDULER
DESCRIPTOR.message_types_by_name['GainSchedulerInfo'] = _GAINSCHEDULERINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GainScheduler = _reflection.GeneratedProtocolMessageType('GainScheduler', (_message.Message,), {
  'DESCRIPTOR' : _GAINSCHEDULER,
  '__module__' : 'modules.control.proto.gain_scheduler_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.GainScheduler)
  })
_sym_db.RegisterMessage(GainScheduler)

GainSchedulerInfo = _reflection.GeneratedProtocolMessageType('GainSchedulerInfo', (_message.Message,), {
  'DESCRIPTOR' : _GAINSCHEDULERINFO,
  '__module__' : 'modules.control.proto.gain_scheduler_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.GainSchedulerInfo)
  })
_sym_db.RegisterMessage(GainSchedulerInfo)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/adapters/proto/adapter_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/adapters/proto/adapter_config.proto',
  package='apollo.common.adapter',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2modules/common/adapters/proto/adapter_config.proto\x12\x15\x61pollo.common.adapter\"\xb1\x0e\n\rAdapterConfig\x12>\n\x04type\x18\x01 \x01(\x0e\x32\x30.apollo.common.adapter.AdapterConfig.MessageType\x12\x37\n\x04mode\x18\x02 \x01(\x0e\x32).apollo.common.adapter.AdapterConfig.Mode\x12!\n\x15message_history_limit\x18\x03 \x01(\x05:\x02\x31\x30\x12\x14\n\x05latch\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\r\n\x05topic\x18\x05 \x01(\t\"\xa6\x0c\n\x0bMessageType\x12\x0f\n\x0bPOINT_CLOUD\x10\x01\x12\x15\n\x11VLP16_POINT_CLOUD\x10:\x12\x07\n\x03GPS\x10\x02\x12\x07\n\x03IMU\x10\x03\x12\x0b\n\x07\x43HASSIS\x10\x04\x12\x10\n\x0cLOCALIZATION\x10\x05\x12\x17\n\x13PLANNING_TRAJECTORY\x10\x06\x12\x0b\n\x07MONITOR\x10\x07\x12\x07\n\x03PAD\x10\x08\x12\x13\n\x0f\x43ONTROL_COMMAND\x10\t\x12\x0e\n\nPREDICTION\x10\n\x12\x18\n\x14PERCEPTION_OBSTACLES\x10\x0b\x12\x1b\n\x17TRAFFIC_LIGHT_DETECTION\x10\x0c\x12\x12\n\x0e\x43HASSIS_DETAIL\x10\r\x12\x10\n\x08\x44\x45\x43ISION\x10\x0e\x1a\x02\x08\x01\x12\n\n\x06\x43\x41NBUS\x10\x0f\x12\x13\n\x0fROUTING_REQUEST\x10\x10\x12\x14\n\x10ROUTING_RESPONSE\x10\x11\x12\x15\n\x11RELATIVE_ODOMETRY\x10\x12\x12\x0c\n\x08INS_STAT\x10\x13\x12\x13\n\x0bHMI_COMMAND\x10\x14\x1a\x02\x08\x01\x12\x0c\n\x08MOBILEYE\x10\x15\x12\r\n\tDELPHIESR\x10\x16\x12\x14\n\x10\x43OMPRESSED_IMAGE\x10\x17\x12\x11\n\rSYSTEM_STATUS\x10\x18\x12\x0e\n\nINS_STATUS\x10\x19\x12\x0f\n\x0bGNSS_STATUS\x10\x1a\x12\x0f\n\x0b\x43ONTI_RADAR\x10\x1b\x12\x0f\n\x0bIMAGE_SHORT\x10\x1c\x12\x0e\n\nIMAGE_LONG\x10\x1d\x12\x0f\n\x0b\x44RIVE_EVENT\x10\x1e\x12\x10\n\x0cGNSS_RTK_OBS\x10\x1f\x12\x10\n\x0cGNSS_RTK_EPH\x10 \x12\x12\n\x0eGNSS_BEST_POSE\x10!\x12\x19\n\x15LOCALIZATION_MSF_GNSS\x10\"\x12\x1a\n\x16LOCALIZATION_MSF_LIDAR\x10#\x12\x1d\n\x19LOCALIZATION_MSF_SINS_PVA\x10$\x12\x0b\n\x07RAW_IMU\x10%\x12\x1b\n\x17LOCALIZATION_MSF_STATUS\x10&\x12\x0f\n\x0bSTATIC_INFO\x10\'\x12\x10\n\x0cRELATIVE_MAP\x10(\x12\x0e\n\nNAVIGATION\x10)\x12\x14\n\x10ULTRASONIC_RADAR\x10*\x12\x11\n\rAUDIO_CAPTURE\x10+\x12\x0f\n\x0bIMAGE_FRONT\x10-\x12\x17\n\x13PANDORA_POINT_CLOUD\x10.\x12\x1e\n\x1aPANDORA_CAMERA_FRONT_COLOR\x10/\x12\x1d\n\x19PANDORA_CAMERA_RIGHT_GRAY\x10\x30\x12\x1c\n\x18PANDORA_CAMERA_LEFT_GRAY\x10\x31\x12\x1d\n\x19PANDORA_CAMERA_FRONT_GRAY\x10\x32\x12\x1c\n\x18PANDORA_CAMERA_BACK_GRAY\x10\x33\x12\x18\n\x14PERCEPTION_LANE_MASK\x10\x34\x12\x0c\n\x08GUARDIAN\x10\x35\x12\x11\n\rGNSS_RAW_DATA\x10\x36\x12\x11\n\rSTREAM_STATUS\x10\x37\x12\x10\n\x0cGNSS_HEADING\x10\x38\x12\r\n\tRTCM_DATA\x10\x39\x12\x11\n\rRACOBIT_RADAR\x10;\x12\x15\n\x11POINT_CLOUD_DENSE\x10<\x12\x19\n\x15POINT_CLOUD_DENSE_RAW\x10=\x12\x17\n\x13VELODYNE_SCAN_DENSE\x10>\x12\x18\n\x14POINT_CLOUD_SPARSE_1\x10?\x12\x1c\n\x18POINT_CLOUD_SPARSE_RAW_1\x10@\x12\x1a\n\x16VELODYNE_SCAN_SPARSE_1\x10\x41\x12\x18\n\x14POINT_CLOUD_SPARSE_2\x10\x42\x12\x1c\n\x18POINT_CLOUD_SPARSE_RAW_2\x10\x43\x12\x1a\n\x16VELODYNE_SCAN_SPARSE_2\x10\x44\x12\x18\n\x14POINT_CLOUD_SPARSE_3\x10\x45\x12\x1c\n\x18POINT_CLOUD_SPARSE_RAW_3\x10\x46\x12\x1a\n\x16VELODYNE_SCAN_SPARSE_3\x10G\x12\x15\n\x11\x43\x41MERA_IMAGE_LONG\x10H\x12\x16\n\x12\x43\x41MERA_IMAGE_SHORT\x10I\x12\x10\n\x0cPLANNING_PAD\x10J\x12\x10\n\x0cSTORYTELLING\x10K\"6\n\x04Mode\x12\x10\n\x0cRECEIVE_ONLY\x10\x00\x12\x10\n\x0cPUBLISH_ONLY\x10\x01\x12\n\n\x06\x44UPLEX\x10\x02\"\\\n\x14\x41\x64\x61pterManagerConfig\x12\x34\n\x06\x63onfig\x18\x01 \x03(\x0b\x32$.apollo.common.adapter.AdapterConfig\x12\x0e\n\x06is_ros\x18\x02 \x01(\x08'
)



_ADAPTERCONFIG_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='apollo.common.adapter.AdapterConfig.MessageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VLP16_POINT_CLOUD', index=1, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHASSIS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLANNING_TRAJECTORY', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONITOR', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAD', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_COMMAND', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREDICTION', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCEPTION_OBSTACLES', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_DETECTION', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHASSIS_DETAIL', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DECISION', index=14, number=14,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANBUS', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUTING_REQUEST', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUTING_RESPONSE', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATIVE_ODOMETRY', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_STAT', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HMI_COMMAND', index=20, number=20,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOBILEYE', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELPHIESR', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSED_IMAGE', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM_STATUS', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_STATUS', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GNSS_STATUS', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTI_RADAR', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_SHORT', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_LONG', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVE_EVENT', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GNSS_RTK_OBS', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GNSS_RTK_EPH', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GNSS_BEST_POSE', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION_MSF_GNSS', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION_MSF_LIDAR', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION_MSF_SINS_PVA', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAW_IMU', index=37, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION_MSF_STATUS', index=38, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATIC_INFO', index=39, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATIVE_MAP', index=40, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAVIGATION', index=41, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ULTRASONIC_RADAR', index=42, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUDIO_CAPTURE', index=43, number=43,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_FRONT', index=44, number=45,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PANDORA_POINT_CLOUD', index=45, number=46,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PANDORA_CAMERA_FRONT_COLOR', index=46, number=47,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PANDORA_CAMERA_RIGHT_GRAY', index=47, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PANDORA_CAMERA_LEFT_GRAY', index=48, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PANDORA_CAMERA_FRONT_GRAY', index=49, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PANDORA_CAMERA_BACK_GRAY', index=50, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCEPTION_LANE_MASK', index=51, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUARDIAN', index=52, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GNSS_RAW_DATA', index=53, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STREAM_STATUS', index=54, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GNSS_HEADING', index=55, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTCM_DATA', index=56, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RACOBIT_RADAR', index=57, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD_DENSE', index=58, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD_DENSE_RAW', index=59, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VELODYNE_SCAN_DENSE', index=60, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD_SPARSE_1', index=61, number=63,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD_SPARSE_RAW_1', index=62, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VELODYNE_SCAN_SPARSE_1', index=63, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD_SPARSE_2', index=64, number=66,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD_SPARSE_RAW_2', index=65, number=67,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VELODYNE_SCAN_SPARSE_2', index=66, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD_SPARSE_3', index=67, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD_SPARSE_RAW_3', index=68, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VELODYNE_SCAN_SPARSE_3', index=69, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMERA_IMAGE_LONG', index=70, number=72,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMERA_IMAGE_SHORT', index=71, number=73,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLANNING_PAD', index=72, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORYTELLING', index=73, number=75,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=289,
  serialized_end=1863,
)
_sym_db.RegisterEnumDescriptor(_ADAPTERCONFIG_MESSAGETYPE)

_ADAPTERCONFIG_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='apollo.common.adapter.AdapterConfig.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RECEIVE_ONLY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUBLISH_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUPLEX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1865,
  serialized_end=1919,
)
_sym_db.RegisterEnumDescriptor(_ADAPTERCONFIG_MODE)


_ADAPTERCONFIG = _descriptor.Descriptor(
  name='AdapterConfig',
  full_name='apollo.common.adapter.AdapterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.common.adapter.AdapterConfig.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='apollo.common.adapter.AdapterConfig.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_history_limit', full_name='apollo.common.adapter.AdapterConfig.message_history_limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latch', full_name='apollo.common.adapter.AdapterConfig.latch', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='apollo.common.adapter.AdapterConfig.topic', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADAPTERCONFIG_MESSAGETYPE,
    _ADAPTERCONFIG_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=1919,
)


_ADAPTERMANAGERCONFIG = _descriptor.Descriptor(
  name='AdapterManagerConfig',
  full_name='apollo.common.adapter.AdapterManagerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='apollo.common.adapter.AdapterManagerConfig.config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_ros', full_name='apollo.common.adapter.AdapterManagerConfig.is_ros', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1921,
  serialized_end=2013,
)

_ADAPTERCONFIG.fields_by_name['type'].enum_type = _ADAPTERCONFIG_MESSAGETYPE
_ADAPTERCONFIG.fields_by_name['mode'].enum_type = _ADAPTERCONFIG_MODE
_ADAPTERCONFIG_MESSAGETYPE.containing_type = _ADAPTERCONFIG
_ADAPTERCONFIG_MODE.containing_type = _ADAPTERCONFIG
_ADAPTERMANAGERCONFIG.fields_by_name['config'].message_type = _ADAPTERCONFIG
DESCRIPTOR.message_types_by_name['AdapterConfig'] = _ADAPTERCONFIG
DESCRIPTOR.message_types_by_name['AdapterManagerConfig'] = _ADAPTERMANAGERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdapterConfig = _reflection.GeneratedProtocolMessageType('AdapterConfig', (_message.Message,), {
  'DESCRIPTOR' : _ADAPTERCONFIG,
  '__module__' : 'modules.common.adapters.proto.adapter_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.adapter.AdapterConfig)
  })
_sym_db.RegisterMessage(AdapterConfig)

AdapterManagerConfig = _reflection.GeneratedProtocolMessageType('AdapterManagerConfig', (_message.Message,), {
  'DESCRIPTOR' : _ADAPTERMANAGERCONFIG,
  '__module__' : 'modules.common.adapters.proto.adapter_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.adapter.AdapterManagerConfig)
  })
_sym_db.RegisterMessage(AdapterManagerConfig)


_ADAPTERCONFIG_MESSAGETYPE.values_by_name["DECISION"]._options = None
_ADAPTERCONFIG_MESSAGETYPE.values_by_name["HMI_COMMAND"]._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/input_debug.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/input_debug.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'modules/control/proto/input_debug.proto\x12\x0e\x61pollo.control\x1a!modules/common/proto/header.proto\"\xe0\x01\n\nInputDebug\x12\x32\n\x13localization_header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12,\n\rcanbus_header\x18\x02 \x01(\x0b\x32\x15.apollo.common.Header\x12\x30\n\x11trajectory_header\x18\x03 \x01(\x0b\x32\x15.apollo.common.Header\x12>\n\x1flatest_replan_trajectory_header\x18\x04 \x01(\x0b\x32\x15.apollo.common.Header'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_INPUTDEBUG = _descriptor.Descriptor(
  name='InputDebug',
  full_name='apollo.control.InputDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localization_header', full_name='apollo.control.InputDebug.localization_header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='canbus_header', full_name='apollo.control.InputDebug.canbus_header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_header', full_name='apollo.control.InputDebug.trajectory_header', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_replan_trajectory_header', full_name='apollo.control.InputDebug.latest_replan_trajectory_header', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=319,
)

_INPUTDEBUG.fields_by_name['localization_header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_INPUTDEBUG.fields_by_name['canbus_header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_INPUTDEBUG.fields_by_name['trajectory_header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_INPUTDEBUG.fields_by_name['latest_replan_trajectory_header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
DESCRIPTOR.message_types_by_name['InputDebug'] = _INPUTDEBUG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InputDebug = _reflection.GeneratedProtocolMessageType('InputDebug', (_message.Message,), {
  'DESCRIPTOR' : _INPUTDEBUG,
  '__module__' : 'modules.control.proto.input_debug_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.InputDebug)
  })
_sym_db.RegisterMessage(InputDebug)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/proto/racobit_radar.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.drivers.radar.racobit_radar.proto import racobit_radar_conf_pb2 as modules_dot_drivers_dot_radar_dot_racobit__radar_dot_proto_dot_racobit__radar__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/proto/racobit_radar.proto',
  package='apollo.drivers',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/drivers/proto/racobit_radar.proto\x12\x0e\x61pollo.drivers\x1a!modules/common/proto/header.proto\x1a\x42modules/drivers/radar/racobit_radar/proto/racobit_radar_conf.proto\"t\n\x1cRacobitClusterListStatus_600\x12\x0f\n\x04near\x18\x01 \x01(\x05:\x01\x30\x12\x0e\n\x03\x66\x61r\x18\x02 \x01(\x05:\x01\x30\x12\x18\n\x0cmeas_counter\x18\x03 \x01(\x05:\x02-1\x12\x19\n\x11interface_version\x18\x04 \x01(\x05\"j\n\x1bRacobitObjectListStatus_60A\x12\x16\n\x0bnof_objects\x18\x01 \x01(\x05:\x01\x30\x12\x18\n\x0cmeas_counter\x18\x02 \x01(\x05:\x02-1\x12\x19\n\x11interface_version\x18\x03 \x01(\x05\"\xf1\x01\n\x15RacobitRadarState_201\x12\x14\n\x0cmax_distance\x18\x01 \x01(\r\x12\x13\n\x0bradar_power\x18\x02 \x01(\r\x12=\n\x0boutput_type\x18\x03 \x01(\x0e\x32(.apollo.drivers.racobit_radar.OutputType\x12\x41\n\rrcs_threshold\x18\x04 \x01(\x0e\x32*.apollo.drivers.racobit_radar.RcsThreshold\x12\x14\n\x0csend_quality\x18\x05 \x01(\x08\x12\x15\n\rsend_ext_info\x18\x06 \x01(\x08\"\xc3\x04\n\x0fRacobitRadarObs\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x16\n\x0e\x63lusterortrack\x18\x02 \x01(\x08\x12\x13\n\x0bobstacle_id\x18\x03 \x01(\x05\x12\x16\n\x0elongitude_dist\x18\x04 \x01(\x01\x12\x14\n\x0clateral_dist\x18\x05 \x01(\x01\x12\x15\n\rlongitude_vel\x18\x06 \x01(\x01\x12\x13\n\x0blateral_vel\x18\x07 \x01(\x01\x12\x0b\n\x03rcs\x18\x08 \x01(\x01\x12\x0f\n\x07\x64ynprop\x18\t \x01(\x05\x12\x1a\n\x12longitude_dist_rms\x18\n \x01(\x01\x12\x18\n\x10lateral_dist_rms\x18\x0b \x01(\x01\x12\x19\n\x11longitude_vel_rms\x18\x0c \x01(\x01\x12\x17\n\x0flateral_vel_rms\x18\r \x01(\x01\x12\x11\n\tprobexist\x18\x0e \x01(\x01\x12\x12\n\nmeas_state\x18\x0f \x01(\x05\x12\x17\n\x0flongitude_accel\x18\x10 \x01(\x01\x12\x15\n\rlateral_accel\x18\x11 \x01(\x01\x12\x17\n\x0foritation_angle\x18\x12 \x01(\x01\x12\x1b\n\x13longitude_accel_rms\x18\x13 \x01(\x01\x12\x19\n\x11lateral_accel_rms\x18\x14 \x01(\x01\x12\x1b\n\x13oritation_angle_rms\x18\x15 \x01(\x01\x12\x0e\n\x06length\x18\x16 \x01(\x01\x12\r\n\x05width\x18\x17 \x01(\x01\x12\x16\n\x0eobstacle_class\x18\x18 \x01(\x05\"\xb8\x02\n\x0cRacobitRadar\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x31\n\x08\x63ontiobs\x18\x02 \x03(\x0b\x32\x1f.apollo.drivers.RacobitRadarObs\x12:\n\x0bradar_state\x18\x03 \x01(\x0b\x32%.apollo.drivers.RacobitRadarState_201\x12I\n\x13\x63luster_list_status\x18\x04 \x01(\x0b\x32,.apollo.drivers.RacobitClusterListStatus_600\x12G\n\x12object_list_status\x18\x05 \x01(\x0b\x32+.apollo.drivers.RacobitObjectListStatus_60A'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_drivers_dot_radar_dot_racobit__radar_dot_proto_dot_racobit__radar__conf__pb2.DESCRIPTOR,])




_RACOBITCLUSTERLISTSTATUS_600 = _descriptor.Descriptor(
  name='RacobitClusterListStatus_600',
  full_name='apollo.drivers.RacobitClusterListStatus_600',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='near', full_name='apollo.drivers.RacobitClusterListStatus_600.near', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='far', full_name='apollo.drivers.RacobitClusterListStatus_600.far', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meas_counter', full_name='apollo.drivers.RacobitClusterListStatus_600.meas_counter', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface_version', full_name='apollo.drivers.RacobitClusterListStatus_600.interface_version', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=280,
)


_RACOBITOBJECTLISTSTATUS_60A = _descriptor.Descriptor(
  name='RacobitObjectListStatus_60A',
  full_name='apollo.drivers.RacobitObjectListStatus_60A',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nof_objects', full_name='apollo.drivers.RacobitObjectListStatus_60A.nof_objects', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meas_counter', full_name='apollo.drivers.RacobitObjectListStatus_60A.meas_counter', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface_version', full_name='apollo.drivers.RacobitObjectListStatus_60A.interface_version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=388,
)


_RACOBITRADARSTATE_201 = _descriptor.Descriptor(
  name='RacobitRadarState_201',
  full_name='apollo.drivers.RacobitRadarState_201',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_distance', full_name='apollo.drivers.RacobitRadarState_201.max_distance', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_power', full_name='apollo.drivers.RacobitRadarState_201.radar_power', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_type', full_name='apollo.drivers.RacobitRadarState_201.output_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rcs_threshold', full_name='apollo.drivers.RacobitRadarState_201.rcs_threshold', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_quality', full_name='apollo.drivers.RacobitRadarState_201.send_quality', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_ext_info', full_name='apollo.drivers.RacobitRadarState_201.send_ext_info', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=632,
)


_RACOBITRADAROBS = _descriptor.Descriptor(
  name='RacobitRadarObs',
  full_name='apollo.drivers.RacobitRadarObs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.RacobitRadarObs.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clusterortrack', full_name='apollo.drivers.RacobitRadarObs.clusterortrack', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_id', full_name='apollo.drivers.RacobitRadarObs.obstacle_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_dist', full_name='apollo.drivers.RacobitRadarObs.longitude_dist', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_dist', full_name='apollo.drivers.RacobitRadarObs.lateral_dist', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_vel', full_name='apollo.drivers.RacobitRadarObs.longitude_vel', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_vel', full_name='apollo.drivers.RacobitRadarObs.lateral_vel', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rcs', full_name='apollo.drivers.RacobitRadarObs.rcs', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynprop', full_name='apollo.drivers.RacobitRadarObs.dynprop', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_dist_rms', full_name='apollo.drivers.RacobitRadarObs.longitude_dist_rms', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_dist_rms', full_name='apollo.drivers.RacobitRadarObs.lateral_dist_rms', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_vel_rms', full_name='apollo.drivers.RacobitRadarObs.longitude_vel_rms', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_vel_rms', full_name='apollo.drivers.RacobitRadarObs.lateral_vel_rms', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probexist', full_name='apollo.drivers.RacobitRadarObs.probexist', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meas_state', full_name='apollo.drivers.RacobitRadarObs.meas_state', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_accel', full_name='apollo.drivers.RacobitRadarObs.longitude_accel', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_accel', full_name='apollo.drivers.RacobitRadarObs.lateral_accel', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oritation_angle', full_name='apollo.drivers.RacobitRadarObs.oritation_angle', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_accel_rms', full_name='apollo.drivers.RacobitRadarObs.longitude_accel_rms', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_accel_rms', full_name='apollo.drivers.RacobitRadarObs.lateral_accel_rms', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oritation_angle_rms', full_name='apollo.drivers.RacobitRadarObs.oritation_angle_rms', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.drivers.RacobitRadarObs.length', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.drivers.RacobitRadarObs.width', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_class', full_name='apollo.drivers.RacobitRadarObs.obstacle_class', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=635,
  serialized_end=1214,
)


_RACOBITRADAR = _descriptor.Descriptor(
  name='RacobitRadar',
  full_name='apollo.drivers.RacobitRadar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.RacobitRadar.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contiobs', full_name='apollo.drivers.RacobitRadar.contiobs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_state', full_name='apollo.drivers.RacobitRadar.radar_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_list_status', full_name='apollo.drivers.RacobitRadar.cluster_list_status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_list_status', full_name='apollo.drivers.RacobitRadar.object_list_status', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1217,
  serialized_end=1529,
)

_RACOBITRADARSTATE_201.fields_by_name['output_type'].enum_type = modules_dot_drivers_dot_radar_dot_racobit__radar_dot_proto_dot_racobit__radar__conf__pb2._OUTPUTTYPE
_RACOBITRADARSTATE_201.fields_by_name['rcs_threshold'].enum_type = modules_dot_drivers_dot_radar_dot_racobit__radar_dot_proto_dot_racobit__radar__conf__pb2._RCSTHRESHOLD
_RACOBITRADAROBS.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_RACOBITRADAR.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_RACOBITRADAR.fields_by_name['contiobs'].message_type = _RACOBITRADAROBS
_RACOBITRADAR.fields_by_name['radar_state'].message_type = _RACOBITRADARSTATE_201
_RACOBITRADAR.fields_by_name['cluster_list_status'].message_type = _RACOBITCLUSTERLISTSTATUS_600
_RACOBITRADAR.fields_by_name['object_list_status'].message_type = _RACOBITOBJECTLISTSTATUS_60A
DESCRIPTOR.message_types_by_name['RacobitClusterListStatus_600'] = _RACOBITCLUSTERLISTSTATUS_600
DESCRIPTOR.message_types_by_name['RacobitObjectListStatus_60A'] = _RACOBITOBJECTLISTSTATUS_60A
DESCRIPTOR.message_types_by_name['RacobitRadarState_201'] = _RACOBITRADARSTATE_201
DESCRIPTOR.message_types_by_name['RacobitRadarObs'] = _RACOBITRADAROBS
DESCRIPTOR.message_types_by_name['RacobitRadar'] = _RACOBITRADAR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RacobitClusterListStatus_600 = _reflection.GeneratedProtocolMessageType('RacobitClusterListStatus_600', (_message.Message,), {
  'DESCRIPTOR' : _RACOBITCLUSTERLISTSTATUS_600,
  '__module__' : 'modules.drivers.proto.racobit_radar_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.RacobitClusterListStatus_600)
  })
_sym_db.RegisterMessage(RacobitClusterListStatus_600)

RacobitObjectListStatus_60A = _reflection.GeneratedProtocolMessageType('RacobitObjectListStatus_60A', (_message.Message,), {
  'DESCRIPTOR' : _RACOBITOBJECTLISTSTATUS_60A,
  '__module__' : 'modules.drivers.proto.racobit_radar_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.RacobitObjectListStatus_60A)
  })
_sym_db.RegisterMessage(RacobitObjectListStatus_60A)

RacobitRadarState_201 = _reflection.GeneratedProtocolMessageType('RacobitRadarState_201', (_message.Message,), {
  'DESCRIPTOR' : _RACOBITRADARSTATE_201,
  '__module__' : 'modules.drivers.proto.racobit_radar_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.RacobitRadarState_201)
  })
_sym_db.RegisterMessage(RacobitRadarState_201)

RacobitRadarObs = _reflection.GeneratedProtocolMessageType('RacobitRadarObs', (_message.Message,), {
  'DESCRIPTOR' : _RACOBITRADAROBS,
  '__module__' : 'modules.drivers.proto.racobit_radar_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.RacobitRadarObs)
  })
_sym_db.RegisterMessage(RacobitRadarObs)

RacobitRadar = _reflection.GeneratedProtocolMessageType('RacobitRadar', (_message.Message,), {
  'DESCRIPTOR' : _RACOBITRADAR,
  '__module__' : 'modules.drivers.proto.racobit_radar_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.RacobitRadar)
  })
_sym_db.RegisterMessage(RacobitRadar)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/velodyne/proto/config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.drivers.velodyne.proto import velodyne_pb2 as modules_dot_drivers_dot_velodyne_dot_proto_dot_velodyne__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/velodyne/proto/config.proto',
  package='apollo.drivers.velodyne',
  syntax='proto2',
  serialized_pb=_b('\n+modules/drivers/velodyne/proto/config.proto\x12\x17\x61pollo.drivers.velodyne\x1a-modules/drivers/velodyne/proto/velodyne.proto\"\xc9\x04\n\x06\x43onfig\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x14\n\x0cscan_channel\x18\x02 \x01(\t\x12\x10\n\x03rpm\x18\x03 \x01(\x01:\x03\x36\x30\x30\x12-\n\x05model\x18\x04 \x01(\x0e\x32\x1e.apollo.drivers.velodyne.Model\x12+\n\x04mode\x18\x15 \x01(\x0e\x32\x1d.apollo.drivers.velodyne.Mode\x12\x0c\n\x04pcap\x18\x05 \x01(\t\x12\x14\n\x0cprefix_angle\x18\x06 \x01(\x05\x12\x18\n\x10\x66iring_data_port\x18\x07 \x01(\x05\x12\x1d\n\x15positioning_data_port\x18\x08 \x01(\x05\x12\x17\n\x0fuse_sensor_sync\x18\t \x01(\x08\x12\x11\n\tmax_range\x18\n \x01(\x01\x12\x11\n\tmin_range\x18\x0b \x01(\x01\x12\x11\n\tmax_angle\x18\x0c \x01(\x01\x12\x11\n\tmin_angle\x18\r \x01(\x01\x12\x16\n\x0eview_direction\x18\x0e \x01(\x01\x12\x12\n\nview_width\x18\x0f \x01(\x01\x12\x1a\n\x12\x63\x61libration_online\x18\x10 \x01(\x08\x12\x18\n\x10\x63\x61libration_file\x18\x11 \x01(\t\x12\x11\n\torganized\x18\x12 \x01(\x08\x12\x1c\n\x14\x63onvert_channel_name\x18\x13 \x01(\t\x12\x10\n\x08npackets\x18\x14 \x01(\x05\x12\x14\n\x0cuse_gps_time\x18\x17 \x01(\x08\x12\x15\n\ruse_poll_sync\x18\x18 \x01(\x08\x12\x15\n\ris_main_frame\x18\x19 \x01(\x08\"\x86\x01\n\x0c\x46usionConfig\x12\x17\n\x0fmax_interval_ms\x18\x01 \x01(\r\x12\x19\n\x11\x64rop_expired_data\x18\x02 \x01(\x08\x12\x16\n\x0e\x66usion_channel\x18\x03 \x01(\t\x12\x15\n\rinput_channel\x18\x04 \x03(\t\x12\x13\n\x0bwait_time_s\x18\x05 \x01(\x02\"\xa4\x01\n\x11\x43ompensatorConfig\x12\x16\n\x0eoutput_channel\x18\x01 \x01(\t\x12%\n\x17transform_query_timeout\x18\x02 \x01(\x02:\x04\x30.02\x12\x1d\n\x0eworld_frame_id\x18\x03 \x01(\t:\x05world\x12\x17\n\x0ftarget_frame_id\x18\x04 \x01(\t\x12\x18\n\x10point_cloud_size\x18\x05 \x01(\r')
  ,
  dependencies=[modules_dot_drivers_dot_velodyne_dot_proto_dot_velodyne__pb2.DESCRIPTOR,])




_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='apollo.drivers.velodyne.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.velodyne.Config.frame_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scan_channel', full_name='apollo.drivers.velodyne.Config.scan_channel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpm', full_name='apollo.drivers.velodyne.Config.rpm', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(600),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='model', full_name='apollo.drivers.velodyne.Config.model', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mode', full_name='apollo.drivers.velodyne.Config.mode', index=4,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pcap', full_name='apollo.drivers.velodyne.Config.pcap', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prefix_angle', full_name='apollo.drivers.velodyne.Config.prefix_angle', index=6,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='firing_data_port', full_name='apollo.drivers.velodyne.Config.firing_data_port', index=7,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positioning_data_port', full_name='apollo.drivers.velodyne.Config.positioning_data_port', index=8,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_sensor_sync', full_name='apollo.drivers.velodyne.Config.use_sensor_sync', index=9,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_range', full_name='apollo.drivers.velodyne.Config.max_range', index=10,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_range', full_name='apollo.drivers.velodyne.Config.min_range', index=11,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_angle', full_name='apollo.drivers.velodyne.Config.max_angle', index=12,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_angle', full_name='apollo.drivers.velodyne.Config.min_angle', index=13,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='view_direction', full_name='apollo.drivers.velodyne.Config.view_direction', index=14,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='view_width', full_name='apollo.drivers.velodyne.Config.view_width', index=15,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibration_online', full_name='apollo.drivers.velodyne.Config.calibration_online', index=16,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibration_file', full_name='apollo.drivers.velodyne.Config.calibration_file', index=17,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='organized', full_name='apollo.drivers.velodyne.Config.organized', index=18,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='convert_channel_name', full_name='apollo.drivers.velodyne.Config.convert_channel_name', index=19,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='npackets', full_name='apollo.drivers.velodyne.Config.npackets', index=20,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_gps_time', full_name='apollo.drivers.velodyne.Config.use_gps_time', index=21,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_poll_sync', full_name='apollo.drivers.velodyne.Config.use_poll_sync', index=22,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_main_frame', full_name='apollo.drivers.velodyne.Config.is_main_frame', index=23,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=705,
)


_FUSIONCONFIG = _descriptor.Descriptor(
  name='FusionConfig',
  full_name='apollo.drivers.velodyne.FusionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_interval_ms', full_name='apollo.drivers.velodyne.FusionConfig.max_interval_ms', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='drop_expired_data', full_name='apollo.drivers.velodyne.FusionConfig.drop_expired_data', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fusion_channel', full_name='apollo.drivers.velodyne.FusionConfig.fusion_channel', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input_channel', full_name='apollo.drivers.velodyne.FusionConfig.input_channel', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wait_time_s', full_name='apollo.drivers.velodyne.FusionConfig.wait_time_s', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=842,
)


_COMPENSATORCONFIG = _descriptor.Descriptor(
  name='CompensatorConfig',
  full_name='apollo.drivers.velodyne.CompensatorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_channel', full_name='apollo.drivers.velodyne.CompensatorConfig.output_channel', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transform_query_timeout', full_name='apollo.drivers.velodyne.CompensatorConfig.transform_query_timeout', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.02),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='world_frame_id', full_name='apollo.drivers.velodyne.CompensatorConfig.world_frame_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("world").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_frame_id', full_name='apollo.drivers.velodyne.CompensatorConfig.target_frame_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='point_cloud_size', full_name='apollo.drivers.velodyne.CompensatorConfig.point_cloud_size', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=1009,
)

_CONFIG.fields_by_name['model'].enum_type = modules_dot_drivers_dot_velodyne_dot_proto_dot_velodyne__pb2._MODEL
_CONFIG.fields_by_name['mode'].enum_type = modules_dot_drivers_dot_velodyne_dot_proto_dot_velodyne__pb2._MODE
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['FusionConfig'] = _FUSIONCONFIG
DESCRIPTOR.message_types_by_name['CompensatorConfig'] = _COMPENSATORCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), dict(
  DESCRIPTOR = _CONFIG,
  __module__ = 'modules.drivers.velodyne.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.velodyne.Config)
  ))
_sym_db.RegisterMessage(Config)

FusionConfig = _reflection.GeneratedProtocolMessageType('FusionConfig', (_message.Message,), dict(
  DESCRIPTOR = _FUSIONCONFIG,
  __module__ = 'modules.drivers.velodyne.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.velodyne.FusionConfig)
  ))
_sym_db.RegisterMessage(FusionConfig)

CompensatorConfig = _reflection.GeneratedProtocolMessageType('CompensatorConfig', (_message.Message,), dict(
  DESCRIPTOR = _COMPENSATORCONFIG,
  __module__ = 'modules.drivers.velodyne.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.velodyne.CompensatorConfig)
  ))
_sym_db.RegisterMessage(CompensatorConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/transform/proto/static_transform_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/transform/proto/static_transform_conf.proto',
  package='apollo.static_transform',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3modules/transform/proto/static_transform_conf.proto\x12\x17\x61pollo.static_transform\"\\\n\rExtrinsicFile\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63hild_frame_id\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08\"F\n\x04\x43onf\x12>\n\x0e\x65xtrinsic_file\x18\x01 \x03(\x0b\x32&.apollo.static_transform.ExtrinsicFile'
)




_EXTRINSICFILE = _descriptor.Descriptor(
  name='ExtrinsicFile',
  full_name='apollo.static_transform.ExtrinsicFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.static_transform.ExtrinsicFile.frame_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_frame_id', full_name='apollo.static_transform.ExtrinsicFile.child_frame_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_path', full_name='apollo.static_transform.ExtrinsicFile.file_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.static_transform.ExtrinsicFile.enable', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=172,
)


_CONF = _descriptor.Descriptor(
  name='Conf',
  full_name='apollo.static_transform.Conf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extrinsic_file', full_name='apollo.static_transform.Conf.extrinsic_file', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=244,
)

_CONF.fields_by_name['extrinsic_file'].message_type = _EXTRINSICFILE
DESCRIPTOR.message_types_by_name['ExtrinsicFile'] = _EXTRINSICFILE
DESCRIPTOR.message_types_by_name['Conf'] = _CONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtrinsicFile = _reflection.GeneratedProtocolMessageType('ExtrinsicFile', (_message.Message,), {
  'DESCRIPTOR' : _EXTRINSICFILE,
  '__module__' : 'modules.transform.proto.static_transform_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.static_transform.ExtrinsicFile)
  })
_sym_db.RegisterMessage(ExtrinsicFile)

Conf = _reflection.GeneratedProtocolMessageType('Conf', (_message.Message,), {
  'DESCRIPTOR' : _CONF,
  '__module__' : 'modules.transform.proto.static_transform_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.static_transform.Conf)
  })
_sym_db.RegisterMessage(Conf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_service_car_to_obu.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.v2x.proto import v2x_car_status_pb2 as modules_dot_v2x_dot_proto_dot_v2x__car__status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_service_car_to_obu.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.modules/v2x/proto/v2x_service_car_to_obu.proto\x12\napollo.v2x\x1a&modules/v2x/proto/v2x_car_status.proto\"&\n\x0cUpdateStatus\x12\x16\n\x07updated\x18\x01 \x02(\x08:\x05\x66\x61lse2N\n\x08\x43\x61rToObu\x12\x42\n\rPushCarStatus\x12\x15.apollo.v2x.CarStatus\x1a\x18.apollo.v2x.UpdateStatus\"\x00'
  ,
  dependencies=[modules_dot_v2x_dot_proto_dot_v2x__car__status__pb2.DESCRIPTOR,])




_UPDATESTATUS = _descriptor.Descriptor(
  name='UpdateStatus',
  full_name='apollo.v2x.UpdateStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='updated', full_name='apollo.v2x.UpdateStatus.updated', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=140,
)

DESCRIPTOR.message_types_by_name['UpdateStatus'] = _UPDATESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UpdateStatus = _reflection.GeneratedProtocolMessageType('UpdateStatus', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTATUS,
  '__module__' : 'modules.v2x.proto.v2x_service_car_to_obu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.UpdateStatus)
  })
_sym_db.RegisterMessage(UpdateStatus)



_CARTOOBU = _descriptor.ServiceDescriptor(
  name='CarToObu',
  full_name='apollo.v2x.CarToObu',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=142,
  serialized_end=220,
  methods=[
  _descriptor.MethodDescriptor(
    name='PushCarStatus',
    full_name='apollo.v2x.CarToObu.PushCarStatus',
    index=0,
    containing_service=None,
    input_type=modules_dot_v2x_dot_proto_dot_v2x__car__status__pb2._CARSTATUS,
    output_type=_UPDATESTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CARTOOBU)

DESCRIPTOR.services_by_name['CarToObu'] = _CARTOOBU

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/proto/map_pnc_junction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.map.proto import map_id_pb2 as modules_dot_map_dot_proto_dot_map__id__pb2
from modules.map.proto import map_geometry_pb2 as modules_dot_map_dot_proto_dot_map__geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/proto/map_pnc_junction.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(modules/map/proto/map_pnc_junction.proto\x12\x0c\x61pollo.hdmap\x1a\x1emodules/map/proto/map_id.proto\x1a$modules/map/proto/map_geometry.proto\"\x92\x02\n\x07Passage\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12#\n\tsignal_id\x18\x02 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12\"\n\x08yield_id\x18\x03 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12&\n\x0cstop_sign_id\x18\x04 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12!\n\x07lane_id\x18\x05 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12(\n\x04type\x18\x06 \x01(\x0e\x32\x1a.apollo.hdmap.Passage.Type\"+\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x45NTRANCE\x10\x01\x12\x08\n\x04\x45XIT\x10\x02\"T\n\x0cPassageGroup\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12&\n\x07passage\x18\x02 \x03(\x0b\x32\x15.apollo.hdmap.Passage\"\xac\x01\n\x0bPNCJunction\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12&\n\x07polygon\x18\x02 \x01(\x0b\x32\x15.apollo.hdmap.Polygon\x12$\n\noverlap_id\x18\x03 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12\x31\n\rpassage_group\x18\x04 \x03(\x0b\x32\x1a.apollo.hdmap.PassageGroup'
  ,
  dependencies=[modules_dot_map_dot_proto_dot_map__id__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__geometry__pb2.DESCRIPTOR,])



_PASSAGE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.hdmap.Passage.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENTRANCE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=360,
  serialized_end=403,
)
_sym_db.RegisterEnumDescriptor(_PASSAGE_TYPE)


_PASSAGE = _descriptor.Descriptor(
  name='Passage',
  full_name='apollo.hdmap.Passage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.Passage.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_id', full_name='apollo.hdmap.Passage.signal_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_id', full_name='apollo.hdmap.Passage.yield_id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_sign_id', full_name='apollo.hdmap.Passage.stop_sign_id', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.hdmap.Passage.lane_id', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.hdmap.Passage.type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PASSAGE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=403,
)


_PASSAGEGROUP = _descriptor.Descriptor(
  name='PassageGroup',
  full_name='apollo.hdmap.PassageGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.PassageGroup.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passage', full_name='apollo.hdmap.PassageGroup.passage', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=405,
  serialized_end=489,
)


_PNCJUNCTION = _descriptor.Descriptor(
  name='PNCJunction',
  full_name='apollo.hdmap.PNCJunction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.PNCJunction.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='apollo.hdmap.PNCJunction.polygon', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overlap_id', full_name='apollo.hdmap.PNCJunction.overlap_id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passage_group', full_name='apollo.hdmap.PNCJunction.passage_group', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=492,
  serialized_end=664,
)

_PASSAGE.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_PASSAGE.fields_by_name['signal_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_PASSAGE.fields_by_name['yield_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_PASSAGE.fields_by_name['stop_sign_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_PASSAGE.fields_by_name['lane_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_PASSAGE.fields_by_name['type'].enum_type = _PASSAGE_TYPE
_PASSAGE_TYPE.containing_type = _PASSAGE
_PASSAGEGROUP.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_PASSAGEGROUP.fields_by_name['passage'].message_type = _PASSAGE
_PNCJUNCTION.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_PNCJUNCTION.fields_by_name['polygon'].message_type = modules_dot_map_dot_proto_dot_map__geometry__pb2._POLYGON
_PNCJUNCTION.fields_by_name['overlap_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_PNCJUNCTION.fields_by_name['passage_group'].message_type = _PASSAGEGROUP
DESCRIPTOR.message_types_by_name['Passage'] = _PASSAGE
DESCRIPTOR.message_types_by_name['PassageGroup'] = _PASSAGEGROUP
DESCRIPTOR.message_types_by_name['PNCJunction'] = _PNCJUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Passage = _reflection.GeneratedProtocolMessageType('Passage', (_message.Message,), {
  'DESCRIPTOR' : _PASSAGE,
  '__module__' : 'modules.map.proto.map_pnc_junction_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Passage)
  })
_sym_db.RegisterMessage(Passage)

PassageGroup = _reflection.GeneratedProtocolMessageType('PassageGroup', (_message.Message,), {
  'DESCRIPTOR' : _PASSAGEGROUP,
  '__module__' : 'modules.map.proto.map_pnc_junction_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.PassageGroup)
  })
_sym_db.RegisterMessage(PassageGroup)

PNCJunction = _reflection.GeneratedProtocolMessageType('PNCJunction', (_message.Message,), {
  'DESCRIPTOR' : _PNCJUNCTION,
  '__module__' : 'modules.map.proto.map_pnc_junction_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.PNCJunction)
  })
_sym_db.RegisterMessage(PNCJunction)


# @@protoc_insertion_point(module_scope)
